@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from __future__ import annotations
@@ -13,8 +13,7 @@ def main():
     args = a121.ExampleArgumentParser().parse_args()
     et.utils.config_logging(args)
 
-    client = a121.Client(**a121.get_client_args(args))
-    client.connect()
+    client = a121.Client.open(**a121.get_client_args(args))
 
     session_config = a121.SessionConfig(
         [
@@ -68,7 +67,7 @@ def main():
 
     print("Disconnecting...")
     pg_process.close()
-    client.disconnect()
+    client.close()
 
 
 class PGUpdater:
