@@ -21,8 +21,7 @@ def main():
     args = a121.ExampleArgumentParser().parse_args()
     et.utils.config_logging(args)
 
-    client = a121.Client(**a121.get_client_args(args))
-    client.connect()
+    client = a121.Client.open(**a121.get_client_args(args))
 
     detector_config = DetectorConfig(
         start_m=1.0,
@@ -60,7 +59,7 @@ def main():
     detector.stop()
 
     print("Disconnecting...")
-    client.disconnect()
+    client.close()
 
 
 class PGUpdater:
