@@ -21,8 +21,7 @@ def main():
     args = a121.ExampleArgumentParser().parse_args()
     et.utils.config_logging(args)
 
-    client = a121.Client(**a121.get_client_args(args))
-    client.connect()
+    client = a121.Client.open(**a121.get_client_args(args))
 
     sensor_config = a121.SensorConfig(
         start_point=600,
@@ -66,7 +65,7 @@ def main():
 
     print("Disconnecting...")
     pg_process.close()
-    client.disconnect()
+    client.close()
 
 
 class PGUpdater:
