@@ -44,6 +44,19 @@ def prf_converter(prf: PRF) -> PRF:
     return PRF(prf)
 
 
+_T = t.TypeVar("_T")
+
+
+def _copy_docstring_from(thing: t.Any) -> t.Callable[[_T], _T]:
+    """Modifies the decorated function by copying over the __doc__ of `thing`"""
+
+    def inner(decoratee: _T) -> _T:
+        decoratee.__doc__ = thing.__doc__
+        return decoratee
+
+    return inner
+
+
 @attrs.mutable(kw_only=True)
 class SubsweepConfig:
     """Subsweep configuration
@@ -98,6 +111,7 @@ class SubsweepConfig:
     )
 
     def _collect_validation_results(self) -> list[ValidationResult]:
+        APPROX_BASE_STEP_LENGTH = 2.5e-3
         validation_results: list[ValidationResult] = []
 
         if self.enable_loopback and self.profile == Profile.PROFILE_2:
@@ -134,6 +148,33 @@ class SubsweepConfig:
                     ]
                 )
 
+        end_point_m = (
+            self.start_point + ((self.num_points - 1) * self.step_length)
+        ) * APPROX_BASE_STEP_LENGTH
+        if end_point_m > self.prf.maximum_measurable_distance:
+            validation_results.extend(
+                [
+                    ValidationError(
+                        self,
+                        "prf",
+                        f"PRF is too high for the measuring end point ({end_point_m:.3f}m), "
+                        + "try lowering the PRF.",
+                    ),
+                    ValidationError(
+                        self,
+                        "num_points",
+                        f"Measuring range is too long for PRF (max {self.prf.mmd:.2f}m), "
+                        + "try decreasing the number of points.",
+                    ),
+                    ValidationError(
+                        self,
+                        "step_length",
+                        f"Measuring range is too long for PRF (max {self.prf.mmd:.2f}m), "
+                        + "try decreasing the step length.",
+                    ),
+                ]
+            )
+
         return validation_results
 
     def validate(self) -> None:
@@ -194,7 +235,7 @@ class SubsweepConfig:
         if not (
             is_divisor_of(SPARSE_IQ_PPC, step_length) or is_multiple_of(SPARSE_IQ_PPC, step_length)
         ):
-            raise ValueError(f"step_length must be a divisor or multiple of {SPARSE_IQ_PPC}")
+            raise ValueError(f"Step length must be a divisor or multiple of {SPARSE_IQ_PPC}")
 
     @property
     def profile(self) -> Profile:
@@ -292,37 +333,8 @@ class SubsweepConfig:
         self._phase_enhancement = value
 
     @property
+    @_copy_docstring_from(PRF)
     def prf(self) -> PRF:
-        """Pulse Repetition Frequency (PRF)
-
-        Pulse Repetition Frequency, PRF, is the frequency at which pulses are sent out from
-        the radar system. The measurement time is approximately proportional to the PRF.
-        The higher the PRF, the shorter the measurement time.
-
-        This parameter sets the Maximum Measurable Distance, MMD, that can be achieved. MMD is the
-        maximum value for the end point, i.e., the start point + (number of points * step length).
-        For example, an MMD of 7.0 m means that the range cannot be set further out than 7.0 m.
-
-        It also sets the Maximum Unambiguous Range, MUR, that can be achieved. MUR is the maximum
-        distance at which an object can be located to guarantee that its reflection corresponds to
-        the most recent transmitted pulse. Objects farther away than the MUR may fold into the
-        measured range. For example, with a MUR of 11.5 m, an object at 13.5 m could become
-        visible at 2 m.
-
-        ================= ======== ====== ======
-        PRF Setting            PRF    MMD    MUR
-        ================= ======== ====== ======
-        PRF_19_5_MHZ [*]_ 19.5 MHz  3.1 m  7.7 m
-        PRF_15_6_MHZ      15.6 MHz  5.1 m  9.6 m
-        PRF_13_0_MHZ      13.0 MHz  7.0 m 11.5 m
-        PRF_8_7_MHZ        8.7 MHz 12.7 m 17.3 m
-        PRF_6_5_MHZ        6.5 MHz 18.5 m 23.1 m
-        PRF_5_2_MHZ        5.2 MHz 24.3 m 28.8 m
-        ================= ======== ====== ======
-
-        .. [*] 19.5MHz is only available for profile 1.
-        """
-
         return self._prf
 
     @prf.setter
