@@ -1,7 +1,13 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
-from .communication import Client, ExplorationProtocol, ServerError, get_exploration_protocol
+from .communication import (
+    Client,
+    ClientError,
+    ExplorationProtocol,
+    ServerError,
+    get_exploration_protocol,
+)
 from .h5_record import (
     _H5PY_STR_DTYPE,
     H5Record,
