@@ -8,7 +8,7 @@ import attrs
 import typing_extensions as te
 
 from acconeer.exptool.a121._core.entities import SensorInfo
-from acconeer.exptool.a121._core.mediators import AgnosticClientFriends, Message
+from acconeer.exptool.a121._core.peripherals.communication.message import Message
 
 from .parse_error import ParseError
 
@@ -22,12 +22,6 @@ class SensorInfoHeader(te.TypedDict):
 class SensorInfoResponse(Message):
     sensor_infos: t.Dict[int, SensorInfo]
 
-    def apply(self, client: AgnosticClientFriends) -> None:
-        if client._sensor_infos == {}:
-            client._sensor_infos = self.sensor_infos
-        else:
-            raise RuntimeError(f"{client} already has sensor infos")
-
     @classmethod
     def parse(cls, header: t.Dict[str, t.Any], payload: bytes) -> SensorInfoResponse:
         try:
