@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 import acconeer.exptool as et
@@ -12,8 +12,7 @@ parser.add_argument("--sensor", type=int, default=1)
 args = parser.parse_args()
 et.utils.config_logging(args)
 
-client = a121.Client(**a121.get_client_args(args))
-client.connect()
+client = a121.Client.open(**a121.get_client_args(args))
 
 detector_config = DetectorConfig(start_m=0.2, end_m=1)
 
@@ -36,4 +35,4 @@ while not interrupt_handler.got_signal:
 
 print("Disconnecting...")
 detector.stop()
-client.disconnect()
+client.close()
