@@ -14,6 +14,7 @@ import numpy as np
 import numpy.typing as npt
 
 from acconeer.exptool import a121
+from acconeer.exptool.a121._core import utils
 from acconeer.exptool.a121._h5_utils import _create_h5_string_dataset
 from acconeer.exptool.a121.algo import (
     APPROX_BASE_STEP_LENGTH_M,
@@ -35,6 +36,7 @@ from ._processors import (
     ProcessorContext,
     ProcessorMode,
     ProcessorResult,
+    ReflectorShape,
     ThresholdMethod,
     calculate_bg_noise_std,
     calculate_loopback_peak_location,
@@ -54,7 +56,6 @@ class DetailedStatus(enum.Enum):
     CONTEXT_MISSING = enum.auto()
     CALIBRATION_MISSING = enum.auto()
     CONFIG_MISMATCH = enum.auto()
-    INVALID_DETECTOR_CONFIG_RANGE = enum.auto()
 
 
 @attrs.frozen(kw_only=True)
@@ -279,7 +280,7 @@ class DetectorConfig(AlgoConfigBase):
     end_m: float = attrs.field(default=3.0)
     """End point of measurement interval in meters."""
 
-    max_step_length: Optional[int] = attrs.field(default=None)  # TODO: Check validity
+    max_step_length: Optional[int] = attrs.field(default=None)
     """Used to limit step length. If no argument is provided, the step length is automatically
     calculated based on the profile."""
 
@@ -298,11 +299,17 @@ class DetectorConfig(AlgoConfigBase):
     """Threshold method"""
 
     peaksorting_method: PeakSortingMethod = attrs.field(
-        default=PeakSortingMethod.HIGHEST_RCS,
+        default=PeakSortingMethod.STRONGEST,
         converter=PeakSortingMethod,
     )
     """Sorting method of estimated distances."""
 
+    reflector_shape: ReflectorShape = attrs.field(
+        default=ReflectorShape.GENERIC,
+        converter=ReflectorShape,
+    )
+    """Reflector shape."""
+
     num_frames_in_recorded_threshold: int = attrs.field(default=100)
     """Number of frames used when calibrating threshold."""
 
@@ -316,6 +323,16 @@ class DetectorConfig(AlgoConfigBase):
     update_rate: Optional[float] = attrs.field(default=50.0)
     """Sets the detector update rate."""
 
+    @start_m.validator
+    def _(self, _: Any, value: float) -> None:
+        if value < Detector.MIN_DIST_M:
+            raise ValueError(f"Cannot start measurements closer than {Detector.MIN_DIST_M}m")
+
+    @end_m.validator
+    def _(self, _: Any, value: float) -> None:
+        if value > Detector.MAX_DIST_M:
+            raise ValueError(f"Cannot measure further than {Detector.MAX_DIST_M}m")
+
     def _collect_validation_results(self) -> list[a121.ValidationResult]:
         validation_results: list[a121.ValidationResult] = []
 
@@ -336,6 +353,24 @@ class DetectorConfig(AlgoConfigBase):
                 )
             )
 
+        if self.max_step_length is not None and (
+            not utils.is_divisor_of(24, self.max_step_length)
+            and not utils.is_multiple_of(24, self.max_step_length)
+        ):
+            valid_step_length = next(
+                sl
+                for sl in range(self.max_step_length, 0, -1)
+                if utils.is_divisor_of(24, sl) or utils.is_multiple_of(24, sl)
+            )
+            validation_results.append(
+                a121.ValidationWarning(
+                    self,
+                    "max_step_length",
+                    "Actual step length will be rounded down "
+                    + f"to the closest valid step length ({valid_step_length}).",
+                )
+            )
+
         return validation_results
 
 
@@ -344,9 +379,9 @@ class DetectorResult:
     distances: Optional[npt.NDArray[np.float_]] = attrs.field(default=None)
     """Estimated distances (m), sorted according to the selected peak sorting strategy."""
 
-    rcs: Optional[npt.NDArray[np.float_]] = attrs.field(default=None)
-    """Estimated radar cross section (dBsm) corresponding to the peak amplitude of the
-    estimated distances.
+    strengths: Optional[npt.NDArray[np.float_]] = attrs.field(default=None)
+    """Estimated reflector strengths corresponding to the peak amplitude of the estimated
+    distances.
     """
 
     near_edge_status: Optional[bool] = attrs.field(default=None)
@@ -354,6 +389,19 @@ class DetectorResult:
     measurement range.
     """
 
+    sensor_calibration_needed: Optional[bool] = attrs.field(default=None)
+    """Indication of sensor calibration needed. The sensor calibration needs to be redone if this
+    indication is set.
+
+    A sensor calibration should be followed by a detector recalibration, by calling
+    :func:`recalibrate_detector`.
+    """
+
+    temperature: Optional[int] = attrs.field(default=None)
+    """Temperature in sensor during measurement (in degree Celsius). Notice that this has poor
+    absolute accuracy.
+    """
+
     processor_results: list[ProcessorResult] = attrs.field()
     """Processing result. Used for visualization in Exploration Tool."""
 
@@ -393,7 +441,7 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
     def __init__(
         self,
         *,
-        client: a121.ClientBase,
+        client: a121.Client,
         sensor_ids: list[int],
         detector_config: DetectorConfig,
         context: Optional[DetectorContext] = None,
@@ -443,6 +491,17 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
         for context in self.context.single_sensor_contexts.values():
             context.session_config_used_during_calibration = self.session_config
 
+    def recalibrate_detector(self) -> None:
+        """Recalibrate detector by running a subset of the calibration routines.
+
+        Once the detector is calibrated, by calling :func:`calibrate_detector`, a sensor
+        calibration should be followed by a detector recalibration.
+        """
+
+        self._validate_ready_for_calibration()
+
+        self._calibrate_offset()
+
     def _calibrate_close_range(self) -> None:
         """Calibrates the close range measurement parameters used when subtracting the direct
         leakage from the measured signal.
@@ -666,12 +725,6 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
     ) -> DetectorStatus:
         """Returns the detector status along with the detector state."""
 
-        if not cls._valid_detector_config_range(config=config):
-            return DetectorStatus(
-                detector_state=DetailedStatus.INVALID_DETECTOR_CONFIG_RANGE,
-                ready_to_start=False,
-            )
-
         if config.end_m < config.start_m:
             return DetectorStatus(
                 detector_state=DetailedStatus.END_LESSER_THAN_START,
@@ -721,10 +774,6 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
             ready_to_start=(detector_state == DetailedStatus.OK),
         )
 
-    @classmethod
-    def _valid_detector_config_range(cls, config: DetectorConfig) -> bool:
-        return cls.MIN_DIST_M <= config.start_m and config.end_m <= cls.MAX_DIST_M
-
     @staticmethod
     def _close_range_calibrated(context: DetectorContext) -> bool:
         has_dl = np.all(
@@ -857,9 +906,11 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
 
         result = {
             sensor_id: DetectorResult(
-                rcs=aggregator_results[sensor_id].estimated_rcs,
+                strengths=aggregator_results[sensor_id].estimated_strengths,
                 distances=aggregator_results[sensor_id].estimated_distances,
                 near_edge_status=aggregator_results[sensor_id].near_edge_status,
+                sensor_calibration_needed=extended_result[0][sensor_id].calibration_needed,
+                temperature=extended_result[0][sensor_id].temperature,
                 processor_results=aggregator_results[sensor_id].processor_results,
                 service_extended_result=aggregator_results[sensor_id].service_extended_result,
             )
@@ -1110,7 +1161,13 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
         """Creates a group plan."""
         step_length = cls._limit_step_length(profile, config.max_step_length)
         breakpoints = cls._m_to_points(breakpoints_m, step_length)
-        hwaas = cls._calculate_hwaas(profile, breakpoints, config.signal_quality, step_length)
+        hwaas = cls._calculate_hwaas(
+            profile,
+            breakpoints,
+            config.signal_quality,
+            step_length,
+            config.reflector_shape,
+        )
 
         extended_breakpoints = cls._add_margin_to_breakpoints(
             profile=profile,
@@ -1152,7 +1209,12 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
 
     @classmethod
     def _calculate_hwaas(
-        cls, profile: a121.Profile, breakpoints: list[int], signal_quality: float, step_length: int
+        cls,
+        profile: a121.Profile,
+        breakpoints: list[int],
+        signal_quality: float,
+        step_length: int,
+        reflector_shape: ReflectorShape,
     ) -> list[int]:
         rlg_per_hwaas = Processor.RLG_PER_HWAAS_MAP[profile]
         hwaas = []
@@ -1162,7 +1224,11 @@ class Detector(Controller[DetectorConfig, Dict[int, DetectorResult]]):
                 APPROX_BASE_STEP_LENGTH_M * breakpoints[idx + 1],
                 cls.HWAAS_MIN_DISTANCE,
             )
-            rlg = signal_quality + 40 * np.log10(subsweep_end_point_m) - np.log10(processing_gain)
+            rlg = (
+                signal_quality
+                + reflector_shape.exponent * 10 * np.log10(subsweep_end_point_m)
+                - np.log10(processing_gain)
+            )
             hwaas_in_subsweep = int(round(10 ** ((rlg - rlg_per_hwaas) / 10)))
             hwaas.append(np.clip(hwaas_in_subsweep, cls.MIN_HWAAS, cls.MAX_HWAAS))
         return hwaas
