@@ -5,7 +5,7 @@ from __future__ import annotations
 
 import logging
 from enum import Enum, auto
-from typing import Callable, Mapping, Optional
+from typing import Callable, Mapping, Optional, cast
 
 import attrs
 import h5py
@@ -46,6 +46,11 @@ from acconeer.exptool.app.new import (
     pidgets,
 )
 from acconeer.exptool.app.new.ui.plugin_components import CollapsibleWidget, SensorConfigEditor
+from acconeer.exptool.app.new.ui.plugin_components.pidgets.hooks import (
+    disable_if,
+    enable_if,
+    parameter_is,
+)
 
 from ._configs import get_high_accuracy_detector_config
 from ._detector import (
@@ -55,6 +60,7 @@ from ._detector import (
     DetectorContext,
     DetectorResult,
     PeakSortingMethod,
+    ReflectorShape,
     ThresholdMethod,
     _load_algo_data,
 )
@@ -165,10 +171,6 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         assert self.client
         result = self._detector_instance.get_next()
 
-        self._frame_count += 1
-
-        self.callback(GeneralMessage(name="rate_stats", data=self.client._rate_stats))
-        self.callback(GeneralMessage(name="frame_count", data=self._frame_count))
         self.callback(GeneralMessage(name="plot", data=result, recipient="plot_plugin"))
 
     @is_task
@@ -318,14 +320,6 @@ class ViewPlugin(DetectorViewPluginBase):
             "Current configuration does not match the configuration "
             + "used during detector calibration. Run detector calibration."
         ),
-        DetailedStatus.INVALID_DETECTOR_CONFIG_RANGE: (
-            "Invalid detector config. Valid measurement"
-            + " range is "
-            + str(Detector.MIN_DIST_M)
-            + "-"
-            + str(Detector.MAX_DIST_M)
-            + "m."
-        ),
     }
 
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
@@ -449,9 +443,21 @@ class ViewPlugin(DetectorViewPluginBase):
                     a121.Profile.PROFILE_5: "5 (longest)",
                 },
             ),
-            "num_frames_in_recorded_threshold": pidgets.IntPidgetFactory(
-                name_label_text="Num frames in rec. thr.",
-                limits=(1, None),
+            "reflector_shape": pidgets.EnumPidgetFactory(
+                name_label_text="Reflector shape",
+                enum_type=ReflectorShape,
+                label_mapping={
+                    ReflectorShape.GENERIC: "Generic",
+                    ReflectorShape.PLANAR: "Planar",
+                },
+            ),
+            "peaksorting_method": pidgets.EnumPidgetFactory(
+                name_label_text="Peak sorting method",
+                enum_type=PeakSortingMethod,
+                label_mapping={
+                    PeakSortingMethod.CLOSEST: "Closest",
+                    PeakSortingMethod.STRONGEST: "Strongest",
+                },
             ),
             "threshold_method": pidgets.EnumPidgetFactory(
                 name_label_text="Threshold method",
@@ -462,24 +468,22 @@ class ViewPlugin(DetectorViewPluginBase):
                     ThresholdMethod.RECORDED: "Recorded",
                 },
             ),
-            "peaksorting_method": pidgets.EnumPidgetFactory(
-                name_label_text="Peak sorting method",
-                enum_type=PeakSortingMethod,
-                label_mapping={
-                    PeakSortingMethod.CLOSEST: "Closest",
-                    PeakSortingMethod.HIGHEST_RCS: "Highest RCS",
-                },
-            ),
             "fixed_threshold_value": pidgets.FloatPidgetFactory(
                 name_label_text="Fixed threshold value",
                 decimals=1,
                 limits=(0, None),
+                hooks=enable_if(parameter_is("threshold_method", ThresholdMethod.FIXED)),
+            ),
+            "num_frames_in_recorded_threshold": pidgets.IntPidgetFactory(
+                name_label_text="Num frames in rec. thr.",
+                limits=(1, None),
             ),
             "threshold_sensitivity": pidgets.FloatSliderPidgetFactory(
                 name_label_text="Threshold sensitivity",
                 decimals=2,
                 limits=(0, 1),
                 show_limit_values=False,
+                hooks=disable_if(parameter_is("threshold_method", ThresholdMethod.FIXED)),
             ),
             "signal_quality": pidgets.FloatSliderPidgetFactory(
                 name_label_text="Signal quality",
@@ -560,10 +564,24 @@ class ViewPlugin(DetectorViewPluginBase):
 
         self.message_box.setText(self.TEXT_MSG_MAP[detector_status.detector_state])
 
-        ready_for_session = app_model.is_ready_for_session()
+        app_model_ready = app_model.is_ready_for_session()
 
-        self.calibrate_detector_button.setEnabled(ready_for_session)
-        self.start_button.setEnabled(ready_for_session and detector_status.ready_to_start)
+        try:
+            cast(SharedState, app_model.backend_plugin_state).config.validate()
+        except a121.ValidationError:
+            config_valid = False
+        else:
+            config_valid = True
+
+        self.calibrate_detector_button.setEnabled(
+            app_model_ready and config_valid and self.config_editor.is_ready
+        )
+        self.start_button.setEnabled(
+            app_model_ready
+            and config_valid
+            and detector_status.ready_to_start
+            and self.config_editor.is_ready
+        )
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
     def _on_sensor_id_update(self, sensor_id: int) -> None:
@@ -583,7 +601,6 @@ class ViewPlugin(DetectorViewPluginBase):
         self.app_model.put_backend_plugin_task(
             "calibrate_detector", on_error=self.app_model.emit_error
         )
-        self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
 
     def _send_defaults_request(self) -> None:
         self.app_model.put_backend_plugin_task("restore_defaults")
@@ -611,7 +628,7 @@ DISTANCE_DETECTOR_PLUGIN = PluginSpec(
     description="Easily measure distance to objects.",
     family=PluginFamily.DETECTOR,
     presets=[
-        PluginPresetBase(name="Low power", preset_id=PluginPresetId.DEFAULT),
+        PluginPresetBase(name="Default", preset_id=PluginPresetId.DEFAULT),
         PluginPresetBase(name="High accuracy", preset_id=PluginPresetId.HIGH_ACCURACY),
     ],
     default_preset_id=PluginPresetId.DEFAULT,
