@@ -34,7 +34,7 @@ from acconeer.exptool.app.new import (
     GridGroupBox,
     Message,
     MiscErrorView,
-    PidgetFactoryMapping,
+    PidgetGroupFactoryMapping,
     PluginFamily,
     PluginGeneration,
     PluginPresetBase,
@@ -44,9 +44,10 @@ from acconeer.exptool.app.new import (
     is_task,
     pidgets,
 )
+from acconeer.exptool.app.new.ui.plugin_components.pidgets.hooks import disable_if, parameter_is
 
 from ._configs import get_long_range_config, get_medium_range_config, get_short_range_config
-from ._detector import Detector, DetectorConfig, DetectorResult, _load_algo_data
+from ._detector import Detector, DetectorConfig, DetectorMetadata, DetectorResult, _load_algo_data
 
 
 @attrs.mutable(kw_only=True)
@@ -133,7 +134,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
                 name="setup",
                 kwargs=dict(
                     detector_config=self.shared_state.config,
-                    sensor_config=Detector._get_sensor_config(self.shared_state.config),
+                    detector_metadata=self._detector_instance.detector_metadata,
                     estimated_frame_rate=self._detector_instance.estimated_frame_rate,
                 ),
                 recipient="plot_plugin",
@@ -151,10 +152,6 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
             raise RuntimeError
         result = self._detector_instance.get_next()
 
-        self._frame_count += 1
-
-        self.callback(GeneralMessage(name="rate_stats", data=self.client._rate_stats))
-        self.callback(GeneralMessage(name="frame_count", data=self._frame_count))
         self.callback(GeneralMessage(name="plot", data=result, recipient="plot_plugin"))
 
 
@@ -173,12 +170,14 @@ class PlotPlugin(DetectorPlotPluginBase):
     def setup(
         self,
         detector_config: DetectorConfig,
-        sensor_config: a121.SensorConfig,
+        detector_metadata: DetectorMetadata,
         estimated_frame_rate: float,
     ) -> None:
         self.detector_config = detector_config
         self.distances = np.linspace(
-            detector_config.start_m, detector_config.end_m, sensor_config.num_points
+            detector_metadata.start_m,
+            detector_config.end_m,
+            detector_metadata.num_points,
         )
 
         self.history_length_s = 5
@@ -432,17 +431,9 @@ class ViewPlugin(DetectorViewPluginBase):
         self.stop_button.setToolTip("Stops the session.\n\nShortcut: Space")
         self.stop_button.clicked.connect(self._send_stop_request)
 
-        self.defaults_button = QPushButton(
-            qta.icon("mdi6.restore", color=BUTTON_ICON_COLOR),
-            "Reset settings and calibrations",
-            self.sticky_widget,
-        )
-        self.defaults_button.clicked.connect(self._send_defaults_request)
-
         button_group = GridGroupBox("Controls", parent=self.sticky_widget)
         button_group.layout().addWidget(self.start_button, 0, 0)
         button_group.layout().addWidget(self.stop_button, 0, 1)
-        button_group.layout().addWidget(self.defaults_button, 1, 0, 1, -1)
 
         sticky_layout.addWidget(button_group)
 
@@ -469,8 +460,8 @@ class ViewPlugin(DetectorViewPluginBase):
         self.scrolly_widget.setLayout(scrolly_layout)
 
     @classmethod
-    def _get_pidget_mapping(cls) -> PidgetFactoryMapping:
-        return {
+    def _get_pidget_mapping(cls) -> PidgetGroupFactoryMapping:
+        service_parameters = {
             "start_m": pidgets.FloatPidgetFactory(
                 name_label_text="Range start",
                 suffix=" m",
@@ -522,9 +513,8 @@ class ViewPlugin(DetectorViewPluginBase):
                     a121.IdleState.READY: "Ready",
                 },
             ),
-            "intra_enable": pidgets.CheckboxPidgetFactory(
-                name_label_text="Enable fast motion detection"
-            ),
+        }
+        intra_parameters = {
             "intra_detection_threshold": pidgets.FloatSliderPidgetFactory(
                 name_label_text="Intra detection threshold",
                 decimals=2,
@@ -543,9 +533,8 @@ class ViewPlugin(DetectorViewPluginBase):
                 limits=(0.01, 20),
                 log_scale=True,
             ),
-            "inter_enable": pidgets.CheckboxPidgetFactory(
-                name_label_text="Enable slow motion detection"
-            ),
+        }
+        inter_parameters = {
             "inter_phase_boost": pidgets.CheckboxPidgetFactory(
                 name_label_text="Enable phase boost"
             ),
@@ -590,6 +579,25 @@ class ViewPlugin(DetectorViewPluginBase):
                 init_set_value=5,
             ),
         }
+        return {
+            pidgets.FlatPidgetGroup(): service_parameters,
+            pidgets.FlatPidgetGroup(): {
+                "intra_enable": pidgets.CheckboxPidgetFactory(
+                    name_label_text="Enable intra (fast) motion detection"
+                ),
+            },
+            pidgets.FlatPidgetGroup(
+                hooks=disable_if(parameter_is("intra_enable", False)),
+            ): intra_parameters,
+            pidgets.FlatPidgetGroup(): {
+                "inter_enable": pidgets.CheckboxPidgetFactory(
+                    name_label_text="Enable inter (slow) motion detection"
+                ),
+            },
+            pidgets.FlatPidgetGroup(
+                hooks=disable_if(parameter_is("inter_enable", False)),
+            ): inter_parameters,
+        }
 
     def on_backend_state_update(self, backend_plugin_state: Optional[SharedState]) -> None:
         if backend_plugin_state is not None and backend_plugin_state.config is not None:
@@ -607,7 +615,6 @@ class ViewPlugin(DetectorViewPluginBase):
         if state is None:
             self.start_button.setEnabled(False)
             self.stop_button.setEnabled(False)
-            self.defaults_button.setEnabled(False)
 
             self.config_editor.set_data(None)
             self.config_editor.setEnabled(False)
@@ -617,14 +624,14 @@ class ViewPlugin(DetectorViewPluginBase):
 
         assert isinstance(state, SharedState)
 
-        self.defaults_button.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
-
         self.config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
         self.config_editor.set_data(state.config)
         self.sensor_id_pidget.set_selected_sensor(state.sensor_id, app_model.connected_sensors)
         self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
-        self.start_button.setEnabled(app_model.is_ready_for_session())
+        self.start_button.setEnabled(
+            app_model.is_ready_for_session() and self.config_editor.is_ready
+        )
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
     def _on_config_update(self, config: DetectorConfig) -> None:
