@@ -5,7 +5,7 @@ from __future__ import annotations
 
 import logging
 from functools import partial
-from typing import Any, Mapping, Optional
+from typing import Any, Optional
 
 from PySide6.QtCore import Signal
 from PySide6.QtWidgets import QVBoxLayout, QWidget
@@ -14,6 +14,7 @@ from acconeer.exptool import a121
 from acconeer.exptool.a121._core import Criticality
 
 from . import pidgets
+from .collapsible_widget import CollapsibleWidget
 from .range_help_view import RangeHelpView
 from .types import PidgetFactoryMapping
 
@@ -26,7 +27,8 @@ class SubsweepConfigEditor(QWidget):
 
     _subsweep_config: Optional[a121.SubsweepConfig]
 
-    _all_pidgets: list[pidgets.Pidget]
+    _subsweep_config_pidgets: dict[str, pidgets.Pidget]
+    _erroneous_aspects: set[str]
 
     SPACING = 15
     PROFILE_LABEL_MAP = {
@@ -94,11 +96,19 @@ class SubsweepConfigEditor(QWidget):
             name_label_tooltip=a121.SubsweepConfig.phase_enhancement.__doc__,
         ),
     }
+    ADVANCED_PARAMETERS = {
+        "receiver_gain",
+        "prf",
+        "enable_tx",
+        "enable_loopback",
+        "phase_enhancement",
+    }
 
     def __init__(self, parent: Optional[QWidget] = None) -> None:
         super().__init__(parent=parent)
 
-        self._all_pidgets = []
+        self._subsweep_config_pidgets = {}
+        self._erroneous_aspects = set()
 
         self._subsweep_config = None
 
@@ -108,18 +118,33 @@ class SubsweepConfigEditor(QWidget):
         self.range_help_view = RangeHelpView(self)
         self.layout().addWidget(self.range_help_view)
 
-        self._subsweep_config_pidgets: Mapping[str, pidgets.Pidget] = {}
+        collapsible_layout = QVBoxLayout()
+
         for aspect, factory in self.SUBSWEEP_CONFIG_FACTORIES.items():
             pidget = factory.create(self)
-            self.layout().addWidget(pidget)
+
+            if aspect in self.ADVANCED_PARAMETERS:
+                collapsible_layout.addWidget(pidget)
+            else:
+                self.layout().addWidget(pidget)
 
             pidget.sig_parameter_changed.connect(
                 partial(self._update_subsweep_config_aspect, aspect)
             )
 
-            self._all_pidgets.append(pidget)
             self._subsweep_config_pidgets[aspect] = pidget
 
+        # Some left margin here will show the hierarchy
+        collapsible_layout.setContentsMargins(11, 0, 0, 0)
+        dummy = QWidget()
+        dummy.setLayout(collapsible_layout)
+        self.layout().addWidget(
+            CollapsibleWidget(
+                label="Advanced",
+                widget=dummy,
+            )
+        )
+
     def sync(self) -> None:
         self._update_ui()
 
@@ -153,8 +178,12 @@ class SubsweepConfigEditor(QWidget):
         self.range_help_view.update(subsweep_config)
         self._subsweep_config = subsweep_config
 
+    @property
+    def is_ready(self) -> bool:
+        return self._erroneous_aspects == set()
+
     def set_read_only(self, read_only: bool) -> None:
-        for pidget in self._all_pidgets:
+        for pidget in self._subsweep_config_pidgets.values():
             pidget.setEnabled(not read_only)
 
     def _update_subsweep_config_aspect(self, aspect: str, value: Any) -> None:
@@ -164,15 +193,20 @@ class SubsweepConfigEditor(QWidget):
         try:
             setattr(self._subsweep_config, aspect, value)
         except Exception as e:
+            self._erroneous_aspects.add(aspect)
             self._subsweep_config_pidgets[aspect].set_note_text(e.args[0], Criticality.ERROR)
+        else:
+            if aspect in self._erroneous_aspects:
+                self._erroneous_aspects.remove(aspect)
 
         self._broadcast()
 
     def handle_validation_results(
         self, results: list[a121.ValidationResult]
     ) -> list[a121.ValidationResult]:
-        for pidget in self._all_pidgets:
-            pidget.set_note_text("")
+        for aspect, pidget in self._subsweep_config_pidgets.items():
+            if aspect not in self._erroneous_aspects:
+                pidget.set_note_text("")
 
         unhandled_results: list[a121.ValidationResult] = []
 
@@ -186,6 +220,12 @@ class SubsweepConfigEditor(QWidget):
         if result.aspect is None or self._subsweep_config is None:
             return False
 
+        if result.aspect in self._erroneous_aspects:
+            # If there is an erroneous aspect in the GUI, we do not want to overwrite that.
+            # Once the erroneous aspect is handled with, the same validation result will
+            # come through here anyway
+            return True
+
         result_handled = False
 
         if result.source == self._subsweep_config:
