@@ -648,7 +648,7 @@ class GUI(QMainWindow):
 
     def advanced_port(self):
         dialog = AdvancedSerialDialog(self.override_baudrate, self)
-        ret = dialog.exec_()
+        ret = dialog.exec()
 
         if ret == QtWidgets.QDialog.Accepted:
             self.override_baudrate = dialog.get_state()
@@ -1109,8 +1109,14 @@ class GUI(QMainWindow):
             return
 
         if isinstance(self.radar.external, self.current_module_info.processor):
-            self.radar.external.update_calibration(self.calibration)
-            self.calibration_ui_state.calibration_status = CalibrationStatus.IN_PROCESSOR
+            try:
+                self.radar.external.update_calibration(self.calibration)
+            except Exception as e:
+                traceback.print_exc()
+                msg = "Failed to apply calibration!\n{}".format(self.format_error(e))
+                self.error_message("{}".format(msg))
+            else:
+                self.calibration_ui_state.calibration_status = CalibrationStatus.IN_PROCESSOR
 
     def update_canvas(self, force_update=False):
         module_label = self.module_dd.currentText()
@@ -1218,6 +1224,12 @@ class GUI(QMainWindow):
 
         self.set_multi_sensors()
 
+    def format_error(self, e):
+        exc_type, exc_obj, exc_tb = sys.exc_info()
+        fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+        err = "{}\n{}\n{}\n{}".format(exc_type, fname, exc_tb.tb_lineno, e)
+        return err
+
     def error_message(self, text, info_text=None):
         if self.under_test:
             raise Exception
@@ -1237,7 +1249,7 @@ class GUI(QMainWindow):
             detailed_text = traceback.format_exc()
             message_box.setDetailedText(detailed_text)
 
-        message_box.exec_()
+        message_box.exec()
 
     def info_handle(self, info, detailed_info=None, blocking=True):
         msg = QtWidgets.QMessageBox(self.main_widget)
@@ -1248,7 +1260,7 @@ class GUI(QMainWindow):
         msg.setWindowTitle("Info")
         msg.setStandardButtons(QtWidgets.QMessageBox.Ok)
         if blocking:
-            msg.exec_()
+            msg.exec()
         else:
             msg.show()
         return msg
@@ -1261,7 +1273,7 @@ class GUI(QMainWindow):
             msg.setDetailedText(detailed_warning)
         msg.setWindowTitle("Warning")
         msg.setStandardButtons(QtWidgets.QMessageBox.Ok | QtWidgets.QMessageBox.Cancel)
-        retval = msg.exec_()
+        retval = msg.exec()
         return retval == 1024
 
     def start_scan(self, from_file=False):
@@ -1294,6 +1306,8 @@ class GUI(QMainWindow):
         sensor_config = self.save_gui_settings_to_sensor_config()
         calibration_config = self.get_calibration_config()
 
+        apply_calibration = self.calibration is not None and self.calibration_ui_state.auto_apply
+
         params = {
             "sensor_config": sensor_config,
             "data_source": "file" if from_file else "stream",
@@ -1302,7 +1316,7 @@ class GUI(QMainWindow):
             "service_params": processing_config,
             "multi_sensor": self.current_module_info.multi_sensor,
             "rss_version": getattr(self, "rss_version", None),
-            "calibration": self.calibration,
+            "calibration": self.calibration if apply_calibration else None,
         }
 
         self.threaded_scan = Threaded_Scan(params, parent=self)
@@ -1328,6 +1342,9 @@ class GUI(QMainWindow):
         if calibration_config:
             calibration_config._state = et.configbase.Config.State.LOADED_READONLY
 
+        if apply_calibration:
+            self.calibration_ui_state.calibration_status = CalibrationStatus.IN_PROCESSOR
+
         self.buttons["connect"].setEnabled(False)
 
         self.set_gui_state("scan_is_running", True)
@@ -1520,6 +1537,7 @@ class GUI(QMainWindow):
             return
 
     def stop_scan(self):
+        self.calibration_ui_state.calibration_status = CalibrationStatus.BUFFERED
         self.sig_scan.emit("stop", "", None)
 
     def unlock_gui(self):
@@ -1840,6 +1858,7 @@ class GUI(QMainWindow):
             should_update_calibration = (
                 self.current_module_info
                 and self.current_module_info.calibration_mapper is not None
+                and self.calibration is None
             )
             if should_update_calibration:
                 self.calibration = data
@@ -2234,7 +2253,6 @@ def main():
     QApplication.setHighDpiScaleFactorRoundingPolicy(
         QtCore.Qt.HighDpiScaleFactorRoundingPolicy.PassThrough,
     )
-    QtCore.QCoreApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
     app = QApplication.instance()
     if app is None:
         app = QApplication(sys.argv)
